<?php

namespace Drupal\dsfr_core;

use Drupal\Core\Controller\ControllerBase;

/**
 * Provides route responses for the container info pages.
 */
class Tools extends ControllerBase {

  /**
   * Checks if the DSFR theme is present or installed
   */
  public function checkTheme() {

    // Get current theme
    $theme_current = \Drupal::config('system.theme')->get('default');
    // Get all themes
    $themes = \Drupal::service('extension.list.theme')->getList(); 

    return [
      'current' => $theme_current,
      'themes' => $themes,
      // Check if DSFR Drupal Theme exists
      'missing' => ( $theme_current != 'dsfr' && !array_key_exists('dsfr', $themes) ) ? true : false
    ];
  }

  /**
   * Check if the current theme has DSFR Regions
   */
  public function checkRegions() {

    $theme = $this->checkTheme();
    $theme_current = $theme['current'];

    $message_region_not_found = $this->t('One or more associated DSFR regions(*) not found for the default theme');
    $message_region_not_found.= ' ('. $theme_current .')';

    return [
      'regions' => system_region_list($theme_current, $show = REGIONS_ALL),
      'not_found' => $message_region_not_found
    ];
  }

  /**
   * Provides a pre-formatted Drupal message that supports HTML
   */
  public function msg($get_msg, $type = 'success') {

    $msg = [ '#markup' => $get_msg ];

    switch($type) {

      case 'warning':
        \Drupal::messenger()->addWarning($msg); 
        break;

      case 'error':
        \Drupal::messenger()->addError($msg); 
        break;

      default:
        \Drupal::messenger()->addStatus($msg); 
    }
  }
}